@@ -137,41 +137,6 @@ void update_font(ASS_Renderer *render_priv)
         change_font_size(render_priv, render_priv->state.font_size);
 }
 
-/**
- * \brief Change border width
- *
- * \param render_priv renderer state object
- * \param info glyph state object
- */
-void change_border(ASS_Renderer *render_priv, double border_x, double border_y)
-{
-    int bord = 64 * border_x * render_priv->border_scale;
-
-    if (bord > 0 && border_x == border_y) {
-        if (!render_priv->state.stroker) {
-            int error;
-            error =
-                FT_Stroker_New(render_priv->ftlibrary,
-                               &render_priv->state.stroker);
-            if (error) {
-                ass_msg(render_priv->library, MSGL_V,
-                        "failed to get stroker");
-                render_priv->state.stroker = 0;
-            }
-            render_priv->state.stroker_radius = -1.0;
-        }
-        if (render_priv->state.stroker && render_priv->state.stroker_radius != bord) {
-            FT_Stroker_Set(render_priv->state.stroker, bord,
-                           FT_STROKER_LINECAP_ROUND,
-                           FT_STROKER_LINEJOIN_ROUND, 0);
-            render_priv->state.stroker_radius = bord;
-        }
-    } else {
-        FT_Stroker_Done(render_priv->state.stroker);
-        render_priv->state.stroker = 0;
-    }
-}
-
 /**
  * \brief Calculate a weighted average of two colors
  * calculates c1*(1-a) + c2*a, but separately for each component except alpha
@@ -246,8 +211,7 @@ static int parse_vector_clip(ASS_Renderer *render_priv,
     struct arg text = args[nargs - 1];
 
     ass_drawing_free(drawing);
-    render_priv->state.clip_drawing =
-        ass_drawing_new(render_priv->library, render_priv->ftlibrary);
+    render_priv->state.clip_drawing = ass_drawing_new(render_priv->library);
     drawing = render_priv->state.clip_drawing;
     if (drawing) {
         drawing->scale = scale;
@@ -566,14 +530,9 @@ char *parse_tag(ASS_Renderer *render_priv, char *p, char *end, double pwr)
     } else if (tag("an")) {
         int val = argtoi(*args);
         if ((render_priv->state.parsed_tags & PARSED_A) == 0) {
-            if (val >= 1 && val <= 9) {
-                int v = (val - 1) / 3;      // 0, 1 or 2 for vertical alignment
-                if (v != 0)
-                    v = 3 - v;
-                val = ((val - 1) % 3) + 1;  // horizontal alignment
-                val += v * 4;
-                render_priv->state.alignment = val;
-            } else
+            if (val >= 1 && val <= 9)
+                render_priv->state.alignment = numpad2align(val);
+            else
                 render_priv->state.alignment =
                     render_priv->state.style->Alignment;
             render_priv->state.parsed_tags |= PARSED_A;
@@ -997,8 +956,8 @@ void process_karaoke_effects(ASS_Renderer *render_priv)
                 x_start = 1000000;
                 x_end = -1000000;
                 for (cur2 = s1; cur2 <= e1; ++cur2) {
-                    x_start = FFMIN(x_start, d6_to_int(cur2->bbox.xMin + cur2->pos.x));
-                    x_end = FFMAX(x_end, d6_to_int(cur2->bbox.xMax + cur2->pos.x));
+                    x_start = FFMIN(x_start, d6_to_int(cur2->bbox.x_min + cur2->pos.x));
+                    x_end = FFMAX(x_end, d6_to_int(cur2->bbox.x_max + cur2->pos.x));
                 }
 
                 dt = (tm_current - tm_start);
