@@ -27,11 +27,9 @@ static void ass_reconfigure(ASS_Renderer *priv)
     ASS_Settings *settings = &priv->settings;
 
     priv->render_id++;
-    ass_frame_unref(priv->images_root);
     ass_cache_empty(priv->cache.composite_cache);
     ass_cache_empty(priv->cache.bitmap_cache);
     ass_cache_empty(priv->cache.outline_cache);
-    priv->images_root = NULL;
 
     priv->width = settings->frame_width;
     priv->height = settings->frame_height;
@@ -148,6 +146,10 @@ void ass_set_fonts(ASS_Renderer *priv, const char *default_font,
 
     ass_reconfigure(priv);
 
+    ass_cache_empty(priv->cache.font_cache);
+    if (priv->shaper)
+        ass_shaper_empty_cache(priv->shaper);
+
     if (priv->fontselect)
         ass_fontselect_free(priv->fontselect);
     priv->fontselect = ass_fontselect_init(priv->library, priv->ftlibrary,
