@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdint.h>
+#include <limits.h>
 #include <inttypes.h>
 
 #include "ass_library.h"
@@ -192,7 +193,7 @@ static int read_digits(char **str, int base, uint32_t *res)
 
     while (1) {
         int digit;
-        if (*p >= '0' && *p < base + '0')
+        if (*p >= '0' && *p < FFMIN(base, 10) + '0')
             digit = *p - '0';
         else if (*p >= 'a' && *p < base - 10 + 'a')
             digit = *p - 'a' + 10;
@@ -327,6 +328,28 @@ int parse_ycbcr_matrix(char *str)
     return YCBCR_UNKNOWN;
 }
 
+/**
+ * \brief converts numpad-style align to align.
+ */
+int numpad2align(int val)
+{
+    if (val < -INT_MAX)
+        // Pick an alignment somewhat arbitrarily. VSFilter handles
+        // INT32_MIN as a mix of 1, 2 and 3, so prefer one of those values.
+        val = 2;
+    else if (val < 0)
+        val = -val;
+
+    int res = ((val - 1) % 3) + 1;  // horizontal alignment
+    if (val <= 3)
+        res |= VALIGN_SUB;
+    else if (val <= 6)
+        res |= VALIGN_CENTER;
+    else
+        res |= VALIGN_TOP;
+    return res;
+}
+
 void ass_msg(ASS_Library *priv, int lvl, const char *fmt, ...)
 {
     va_list va;
